@@ -21,6 +21,7 @@
 # Local
 from base.g import *
 from base import device, utils
+from ui_utils import load_pixmap
 
 # Std Lib
 import sys
@@ -39,8 +40,7 @@ class PluginForm(PluginForm_base):
         
         PluginForm_base.__init__(self,parent,name,modal,fl)
         
-        icon = QPixmap(os.path.join(prop.image_dir, 'HPmenu.png'))
-        self.setIcon(icon)
+        self.setIcon(load_pixmap('prog', '48x48'))
         
         self.setTitleFont(QFont("Helvetica", 16))
         
